Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func InitLogger ¶
InitLogger initializes and returns a Zap logger with Lumberjack for log rotation. give it a name to use for the log file
func InitWALLogger ¶
Types ¶
Click to show internal directories.
Click to hide internal directories.